#
# spec file for package python-barbicanclient
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname python-barbicanclient
Name:           python-barbicanclient
Version:        4.1.0
Release:        2.3
Summary:        Client for the Barbican Key Management API
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/p/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-cliff >= 1.15.0
BuildRequires:  python-devel
BuildRequires:  python-keystoneclient >= 2.0.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-requests >= 2.10.0
BuildRequires:  python-requests-mock >= 1.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-cliff >= 1.15.0
Requires:       python-keystoneclient >= 2.0.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-pbr >= 1.6
Requires:       python-requests >= 2.10.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
OpenStack Key Management API client - Python 2.x
This is a client for the Barbican Key Management API. This package includes a
Python library for accessing the API (the barbicanclient module), and a
command-line script (barbican).

This package contains the Python 2.x module.

%package doc
Summary:        Documentation for OpenStack Key Management API Client
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
Documentation for the client library for interacting with
Openstack Key Management API

%prep
%setup -q -n %{name}-%{version}

# Remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}

%build
%{py2_build}
%{__python2} setup.py build_sphinx

%install
%{py2_install}

%check
%{__python2} setup.py testr

%files
%doc README.rst
%license LICENSE
%{python2_sitelib}/python_barbicanclient-%{version}-py?.?.egg-info
%{python2_sitelib}/barbicanclient
%{_bindir}/barbican

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Fri Sep  2 2016 tbechtold@suse.com
  update to version 4.1.0
  * Updated from global requirements
  * Fix jenkins failing on coverage report
  * Fixed python-barbicanclient functional tests
  * Remove unused import
  * Update mailmap for Douglas Mendizábal
  * Update the home-page with developer documentation link
  * Issue deprecation message for the barbican CLI
  * Censoring secrets payload value from debug log
  * Fix argument order for assertEqual to (exp, obs)
  * Fixed barbican client order list
  * Display error description
* Mon Aug  1 2016 tbechtold@suse.com
- Update _service and switch to upstream spec file
* Thu May 26 2016 johannes.grassler@suse.com
- Update to 4.0.1
  4.0.1
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
  4.0.0
  * Replace assertEqual(None, *
  * Updated from global requirements
  * Use six.moves.urllib.parse to replace urlparse
  * Updated from global requirements
  * Remove argparse from requirements
  * Updated from global requirements
  * Updated from global requirements
  * Replace deprecated keystoneclient...exceptions
  * Update typos
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Deprecated tox -downloadcache option removed
  * Remove py26 support
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Update Readme to include new/updated CLI commands
  * Allow tox to be able to run independent functional tests
  * Make CLI Order's type field a required argument
  * Remove invalid skipping of tests
  * Fix Secrets Filter
  * Updated from global requirements
  * Updated from global requirements
  * README.rst devstack link not properly displayed
  * improve readme contents
  * Updated from global requirements
  * Add to_dict method to EntityFormatter
  * Updated from global requirements
  * Part 3: Adding ACL functional tests
  * Updated from global requirements
  * Initialize optional attributes in CA object
  * Fix keystone version selection
  * Part 2: Adding ACL support for CLI commands and docs
  * Fix incorrect error when performing Barbican Secret Update
  * Part 1: Adding ACL support for Client API
  * Fix error where barbican order create returns invalid error
  * Create Openstack CLI plugin for Barbican
  * Fix OS_PROJECT_ID not getting read by client
  * Remove Client V1 Behaviors
  * enable barbican help without authentication
  * Fix barbican-client README.rst
  * Add functional test for updating a Secret
  * Remove test behaviors abstraction for containers smoke tests
  * Remove test behaviors abstraction for orders smoke tests
  * Remove test behaviors abstraction for secrets smoke tests
  * Remove test behaviors abstraction for containers
  * Remove test behaviors abstraction for orders
  * Remove test behaviors abstraction for secrets
  * Create Common functions used for cleaning up items used for testing
  * Add epilog to parser
  * Add Unit Tests for Store and Update Payload when Payload is zero
  * Allow Barbican Client Secret Update Functionality
* Wed Sep 16 2015 tbechtold@suse.com
- update to 3.3.0:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Add ability to add and list CAs
  * Remove unneeded dependency in tox.ini
  * Adding Documentation for running Functional Tests on the Python-Barbican Client
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Added secret type command line option
  * Updated from global requirements
  * New mock release(1.1.0) broke unit/function tests
  * Enable endpoint filter parameters for the CLI
  * Updated from global requirements
  * Use keystone discovery instead of endpoint_override
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Drop incubating theme from docs
  * Remove tempest config dependency in functional tests
  * Add capability of specifying Barbican version to client
  * Remove instances of _base_url
  * Re-merge CLI test update for auth URL and version
  * Add CLI smoke functional tests for containers
  * Create behaviors for secrets
  * Pass in keystone version and correct v2 URL to CLI
  * Add support for certificate order
  * Updated from global requirements
  * Adding new tests to cover failure scenarios
  * Drop use of 'oslo' namespace package
  * Updated from global requirements
  * Add Secret CLI smoke tests
  * Fix bug in CLI authentication
  * Updated from global requirements
  * Refactored barbican.py for better testability
  * Update stdout and stderr capture in functional tests
  * Use keystoneclient to get endpoint if it's empty
  * Initial setup for command line tests
  * Fixing misspelling in client docstring
  * Adding support for token based authentication
  * Cleaning up validate_ref()
  * Update README to work with release tools
  * Cleaning up Keystone auth tests
  * Excluding tests from coverage report
  * Fix the clientrc file to match defaults and add docs
  * Updating client and client docs for accuracy
  * Porting over more documentation to RST from cli wiki
  * Uncap library requirements for liberty
  * Adding payload flag to get secret
  * Raising errors from the client instead of ksclient
  * Fix order listing on the command line
  * Fixing the broken functional tests
  * Use the ksc Adapter instead of custom HTTPClient
- Adjust Requires according to requirements.txt
* Thu Apr 23 2015 tbechtold@suse.com
- Switch to version 3.0.3
* Tue Apr 21 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.1.0.post1:
  * Update README to work with release tools
  3.1.0
  * Excluding tests from coverage report
  * Uncap library requirements for liberty
* Sat Apr 18 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post13:
  * Raising errors from the client instead of ksclient
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post11:
  * Fix the clientrc file to match defaults and add docs
  * Updating client and client docs for accuracy
  * Porting over more documentation to RST from cli wiki
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post7:
  * Adding payload flag to get secret
* Mon Apr 13 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post6:
  * Use the ksc Adapter instead of custom HTTPClient
* Sun Apr 12 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post4:
  * Fix order listing on the command line
* Fri Apr 10 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post3:
  * Fixing the broken functional tests
* Wed Apr  1 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post2:
  3.0.3
  * Negative tests for orders
* Tue Mar 31 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post85:
  * Fix --decrypt command line option
  * Fix order creation on the command line
  * Don't ignore payload_content_encoding if set
* Sat Mar 28 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post80:
  * Consolidate Payload Exceptions
* Wed Mar 25 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post78:
  * Container negative tests
  * Second set of negative secrets tests
* Tue Mar 24 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post74:
  * Updated from global requirements
  * First set of negative functional test for secrets
* Thu Mar 19 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post71:
  * Fix smoke test for client with bad data set
  * Fixed deprecated type and encoding test and encoding bug
  * Removing assertItemsEqual workaround, fixed upstream
* Thu Mar 19 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post67:
  * Fixes tests on invalid payload secret creation and adds new exception
* Wed Mar 18 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post66:
  * Ensuring secret ref is not none with payload
  * Added new exception, renamed test, and adjusted test
  * Fixed max payload size error
  * Fix secret-store empty-key filtering bug
* Mon Mar 16 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post60:
  * Enable usage of 'payload' path to fetch decrypted secrets
* Sun Mar 15 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post58:
  * Don't use tempest log
* Sat Mar 14 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post56:
  * Deprecate setting the payload type and encoding
  * Use functional_test.conf for devstack gate
* Thu Mar 12 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post52:
  * Fix when submitting with empty string, none and zero
* Wed Mar 11 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post50:
  * Fix delete a secret that does not exist
  * Do not filter empty strings
* Tue Mar 10 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post46:
  * Pass correct api object to Container constructor
* Sun Mar  8 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post44:
  * Refactor test modules
* Sat Mar  7 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post42:
  * Moved parameterized test from smoke to functional
* Fri Mar  6 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post40:
  * Add default max payload to functional test conf registry
  * Adds positive orders functional tests
  * Additional requests-mock testing
* Thu Mar  5 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post34:
  * Remove cyclical dependency
  * Convert CRUD tests to requests-mock
* Wed Mar  4 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post30:
  * Updated functional tests to use both identity v2 and v3
  * Add secret_type to Secret constructor
* Mon Mar  2 2015 tbechtold@suse.com
- Update Requires
- Add -test package
* Mon Mar  2 2015 tbechtold@suse.com
- Initial version
